#!/usr/bin/env python

import os
import re

FILES = (
    '/var/log/php-fpm/php-slow.log.1',
    '/var/log/php-fpm/php-slow.log'
)


def log_reader():
    for filename in [x for x in FILES if os.path.exists(x)]:
        with open(filename) as fh:
            for line in fh:
                yield line


def find_slow_community_modules(loglines):
    newrequest = True
    for line in loglines:
        if '[pool www] pid' in line:
            timestamp = line[1:21]
            newrequest = True

        if newrequest:
            try:
                vendor, module = re.search('app/code/(?:local|community)/(.+?)/(.+?)/', line).groups()
            except AttributeError:
                continue

            modid = vendor + '_' + module
            yield "{} {}".format(timestamp, modid)
            newrequest = False


def main():
    for item in find_slow_community_modules(log_reader()):
        print(item)


if __name__ == '__main__':
    main()
