import logging
import socket
import requests

logger = logging.getLogger(__name__)


def _try_post(url, data=None):
    response = requests.post(url, headers={
        'Authorization': 'Token {}'.format(get_hypernode_api_token()),
        'Content-Type': 'application/json',
        'Accept': 'application/json',
        'User-Agent': '{}:{}'.format(
            socket.getfqdn(), 'hypernode-kamikaze'
        )
    }, json=data)
    response.raise_for_status()
    return response.json()


def get_hypernode_api_token():
    try:
        with open('/etc/hypernode/hypernode_api_token', 'r') as f:
            hypernode_api_token = f.read()
    except IOError:
        logger.error('Hypernode API token not provisioned on this node yet.')
        exit(1)
    else:
        return hypernode_api_token.replace('\n', '')
