from __future__ import (absolute_import, division, print_function, unicode_literals)
import logging
import os

from kamikaze.common.api import _try_post
from kamikaze.utils import get_app_name
from .checks import service_checks
from kamikaze.common.settings import ONBOARDING_STATE_PATH, ONBOARDING_API_ENDPOINT

logger = logging.getLogger(__name__)


def state_path_parent_exists():
    return os.path.isdir(os.path.dirname(ONBOARDING_STATE_PATH))


def ensure_working_directory_exists():
    if not os.path.isdir(ONBOARDING_STATE_PATH):
        os.mkdir(ONBOARDING_STATE_PATH)


def call_event_hook(events):
    logger.debug("Calling event hook with events: %s" % events)
    app_name = get_app_name()
    data = {
        'app': app_name,
        'events': events
    }
    url = ONBOARDING_API_ENDPOINT.format(app_name)
    _try_post(url, data=data)


def main():
    logging.basicConfig(level=logging.ERROR)
    logger.debug("Starting Onboarding script")

    if state_path_parent_exists():
        ensure_working_directory_exists()
        successful_checks = []
        for check_cls in service_checks:
            check = check_cls()
            success, success_time = check.execute()
            if success:
                successful_checks.append((check, success_time))

        if successful_checks:
            call_event_hook({c.name: t.isoformat() for c, t in successful_checks})
            for check, _ in successful_checks:
                check.mark_check_done()
    else:
        logger.debug(
            "The parent of the state path does not exist. "
            "Perhaps this is a Vagrant that has been messed "
            "with or a not fully provisioned Hypernode? Skipping"
        )
