from __future__ import print_function
from argparse import ArgumentParser
from subprocess import check_output, check_call

from kamikaze.utils import is_xenial


def get_php_versions():
    return check_output(
        ['phpquery', '-V']
    ).strip().split('\n')


def process_args():
    parser = ArgumentParser(
        description='Set the PHP version'
    )
    parser.add_argument(
        'version', help='The PHP version',
        choices=get_php_versions()
    )
    return parser.parse_args()


def disable_fpm_service(old_version):
    check_call(['systemctl', 'disable', 'php{}-fpm'.format(old_version)])


def stop_fpm_service(old_version):
    check_call(['systemctl', 'stop', 'php{}-fpm'.format(old_version)])


def update_alternatives(new_version):
    new_php_location = check_output(['which', 'php' + new_version]).strip()

    check_call(['update-alternatives',
                '--set',
                'php',
                new_php_location,
                ])


def enable_fpm_service(new_version):
    check_call(['systemctl', 'enable', 'php{}-fpm'.format(new_version)])


def start_fpm_service(new_version):
    check_call(['systemctl', 'start', 'php{}-fpm'.format(new_version)])


def switch_php(new_version):
    php_versions_to_disable = get_php_versions()
    php_versions_to_disable.remove(new_version)

    for old_version in php_versions_to_disable:
        disable_fpm_service(old_version)
        stop_fpm_service(old_version)

    update_alternatives(new_version)
    enable_fpm_service(new_version)
    start_fpm_service(new_version)


def exit_on_precise():
    if not is_xenial():
        print('This script cannot be used in precise')
        exit(1)


def main():
    exit_on_precise()
    args = process_args()
    switch_php(new_version=args.version)

if __name__ == '__main__':
    main()
